Learn R Programming

mpMap2 (version 1.0.4)

[,rawSymmetricMatrix,index,index,logical-method: Internal operators for mpMap2

Description

Internal operators, used to modify mpcross objects.

Usage

# S4 method for rawSymmetricMatrix,index,index,logical
[(x, i, j, ..., drop = TRUE)

# S4 method for rawSymmetricMatrix,index,index,missing [(x, i, j, ..., drop = TRUE)

# S4 method for rawSymmetricMatrix,missing,missing,missing [(x, i, j, ..., drop = TRUE)

# S4 method for rawSymmetricMatrix,matrix,missing,missing [(x, i, j, ..., drop = TRUE)

# S4 method for geneticData,assignFounderPattern +(e1, e2)

# S4 method for mpcross,assignFounderPattern +(e1, e2)

# S4 method for mpcrossMapped,assignFounderPattern +(e1, e2)

# S4 method for geneticData,assignFounderPatternPrototype +(e1, e2)

# S4 method for mpcross,assignFounderPatternPrototype +(e1, e2)

# S4 method for mpcrossMapped,assignFounderPatternPrototype +(e1, e2)

# S4 method for geneticData,biparentalDominant +(e1, e2)

# S4 method for mpcross,biparentalDominant +(e1, e2)

# S4 method for geneticData,fixedNumberOfFounderAlleles +(e1, e2)

# S4 method for mpcross,fixedNumberOfFounderAlleles +(e1, e2)

# S4 method for geneticData,multiparentSNP +(e1, e2)

# S4 method for mpcross,multiparentSNP +(e1, e2)

# S4 method for geneticData,multiparentSNPPrototype +(e1, e2)

# S4 method for mpcross,multiparentSNPPrototype +(e1, e2)

# S4 method for mpcross,removeHets +(e1, e2)

# S4 method for geneticData,normalPhenotype +(e1, e2)

# S4 method for mpcross,normalPhenotype +(e1, e2)

Arguments

x

object from which to extract element(s)

i, j

indices specifying elements to extract or replace

...

Currently unused

drop

If TRUE the result is coerced to the lowest possible dimension

e1

Object one

e2

Object two

Value

Various. Not for external use.

Modified version of the input object. The class of the output depends on the class of the input.

Details

These operators are used to combine objects in order to apply a function. For example, e1 + biparentalDominant() returns the biparental design e1, with all markers converted to dominant markers. Consult the documentation on the individual functions, rather than this list of operators.